@@ -2,7 +2,7 @@ import asyncio
 import functools
 import sys
 from asyncio import AbstractEventLoop
-from typing import Any, Callable
+from typing import Any, Callable, Optional
 
 try:  # pragma: no cover
     _ = _patch_loop  # noqa
@@ -12,19 +12,54 @@ except NameError:
         from nest_asyncio import _patch_loop, apply
     except ImportError:  # pragma: no cover
 
-        def _noop(*args: Any, **kwargs: Any) -> None:
+        def _noop(*_: Any, **__: Any) -> None:
             pass
 
         _patch_loop = apply = _noop
 
 
+try:
+    from trio._core._run import GLOBAL_RUN_CONTEXT
+except ImportError:  # pragma: no cover
+    GLOBAL_RUN_CONTEXT = object()
+
+
+def is_trio_not_running() -> bool:
+    return not hasattr(GLOBAL_RUN_CONTEXT, "runner")
+
+
+def get_current_loop() -> Optional[Any]:  # pragma: no cover
+    try:
+        return asyncio.get_running_loop()  # type: ignore
+    except RuntimeError:
+        return asyncio.new_event_loop()
+    except AttributeError:  # Only for 3.6 case, can be removed in future
+        return asyncio.get_event_loop()
+
+
 def is_async_debug_available(loop: Any = None) -> bool:
     if loop is None:
-        loop = asyncio.get_event_loop()
+        loop = get_current_loop()
 
     return bool(loop.__class__.__module__.lstrip("_").startswith("asyncio"))
 
 
+def verify_async_debug_available() -> None:
+    if not is_trio_not_running():
+        raise RuntimeError(
+            "Can not evaluate async code with trio event loop. "
+            "Only native asyncio event loop can be used for async code evaluating."
+        )
+
+    if not is_async_debug_available():
+        cls = get_current_loop().__class__
+
+        raise RuntimeError(
+            f"Can not evaluate async code with event loop {cls.__module__}.{cls.__qualname__}. "
+            "Only native asyncio event loop can be used for async code evaluating."
+        )
+
+
 def patch_asyncio() -> None:
     if hasattr(sys, "__async_eval_patched__"):  # pragma: no cover
         return
@@ -69,4 +104,9 @@ def patch_asyncio() -> None:
 
 patch_asyncio()
 
-__all__ = ["patch_asyncio", "is_async_debug_available"]
+__all__ = [
+    "patch_asyncio",
+    "get_current_loop",
+    "is_async_debug_available",
+    "verify_async_debug_available",
+]
